%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Makes plots of thermal noise from scaling calculations and plots them
%%% against the L1 sensitivity curve from LIGO-G1500904.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

%% Input parameters:

% L1 strain sensitivity
filename = 'Sensitivty_20150606.txt';
Data = importdata(filename);
freq = Data(:,1);
L1sens = Data(:,2);

% IFO length
L = 4000; % LIGO arm length in meters

% Optic Names for plots
LegendStrings = [...
    {'L1 Sensitivity'},...
    {'GWINC Prediction'},...
    {'TNI 1'},...
    {'TNI 2'},...
    {'TNI 3'},...
    {'TNI 4'},...
    {'TNC'}...
    ];

% coating noise at 100 Hz prediction from GWINC for aLIGO:
S_gwinc = 1.81e-47; % IFO power spectral density at 100 Hz in units of Hz^-1
Sens_gwinc = (freq.^-2) * S_gwinc * 100^2;


% first, the measured optics
d = [...     % Coating thickness in microns
    4.55,... % TNI 1
    5.41,... % TNI 2
    4.21,... % TNI 3
    3.81,... % TNI 4
    4.53...  % TNC
    ];

w = [...     % Beam spot size in microns
    160,...  % TNI 1
    160,...  % TNI 2
    160,...  % TNI 3
    160,...  % TNI 4
    182 ...  % TNC
    ];

a = [...     % Optic radius in cm
    5.08,... % TNI 1
    5.08,... % TNI 2
    5.08,... % TNI 3
    5.08,... % TNI 4
    1.27...  % TNC
    ];

H = [...     % Optic height in cm
    10.16,...% TNI 1
    10.16,...% TNI 2
    10.16,...% TNI 3
    10.16,...% TNI 4
    0.635... % TNC
    ];
    
S = 1e-36 * [...%measured displacement sensitivity in m/Hz
    10.6,... % TNI 1
    8.82,... % TNI 2
    7.79,... % TNI 3
    6.84,... % TNI 4
    11.0...  % TNC
    ];

% second, the optics we're predicting:

d_pred = [... % Coating thickness in microns
    2.8,...   % ITM
    5.9...   % ETM
    ];

w_pred = [... % Beam spot size in microns
    53000,... % ITM
    62000 ... % ETM
    ];

a_pred = [... % Optic radius in cm
    17,...    % ITM
    17 ...    % ETM
    ];

H_pred = [... % Optic height in cm
    20,...    % ITM
    20 ...    % ETM
    ];

% bunch of conversions to MKS units

d = d*1e-6;
d_pred = d_pred*1e-6;
w = w*1e-6;
w_pred = w_pred*1e-6;
a = a*1e-2;
a_pred = a_pred*1e-2;
H = H*1e-2;
H_pred = H_pred*1e-2;

% colors for plots
ColorSet=varycolor(length(d)+2);


%% Simple Scaling

% Calculate displacement sensitivity for individual mirrors
S_pred = zeros(length(d),length(d_pred));

for i1 = 1:length(d)
    for i2 = 1:length(d_pred)
        S_pred(i1,i2) = d_pred(i2)/d(i1) * (w(i1)/w_pred(i2))^2 * S(i1);
    end
end

% Calculate strain sensitivity for the whole IFO

S_ifo = 2*sum(S_pred,2)/L^2;
        

% Calculate whole frequency spectrum

Sens = zeros(length(freq),length(S_ifo));

for i1 = 1:length(S_ifo)
    Sens(:,i1) = (freq.^-2) * S_ifo(i1) * 100^2;
end

% Convert to amplitude spectral density
Asens_simple = sqrt(Sens);

% Plot like crazy
f = figure(...
    'paperunits','inches',...
    'units','inches',...
    'papersize',[8,5],...
    'paperposition',[0,0,8,5],...
    'position',[5,5,8,5]);
h = zeros(size(ColorSet,1),1);
for i1 = 1:size(ColorSet,1)
    x = freq;
    if i1 == 1
        y = L1sens;
    elseif i1 == 2
        y = sqrt(Sens_gwinc);
    else
        y = Asens_simple(:,i1-2);
    end
    C = ColorSet(i1,:);
    h(i1) = loglog(x,y,'color',C,'linewidth',2);
    hold on
end

xlim([10,6e3]);
ylim([1e-24,1e-20])
xlabel('Frequency [Hz]','fontsize',18,'fontweight','demi');
ylabel('Strain [Hz^{-1/2}]','fontsize',18,'fontweight','demi');
set(gca,'linewidth',2,'fontsize',15,'fontweight','demi');
l=legend(h,LegendStrings);        

print(f,'SimpleScaling.pdf','-dpdf');
print(f,'SimpleScaling.png','-dpng','-r500');

Data = [freq,Asens_simple];
csvwrite('SimpleScalingData.csv',Data);

%% Liu and Thorne Scaling

% Input of Energy values
% These values are calculated using LiuThorne.m
Cftm = [... % Finite substrate correction factor from Liu & Thorne, eqn 60
    0.9973,... % TNI 1
    0.9973,... % TNI 2
    0.9973,... % TNI 3
    0.9973,... % TNI 4
    1.0259...  % TNC
    ];

Cftm_pred = [... % Finite substrate correction factor for predicted optics
    0.7099,... % ITM
    0.6610 ... % ETM
    ];

% Calculate displacement sensitivity for individual mirrors
S_pred = zeros(length(d),length(d_pred));

for i1 = 1:length(d)
    for i2 = 1:length(d_pred)
        S_pred(i1,i2) = ...
              d_pred(i2)/d(i1)...
            * Cftm_pred(i2)/Cftm(i1)...
            * (w(i1)/w_pred(i2))^2 ...
            * S(i1);
    end
end

% Calculate strain sensitivity for the whole IFO

S_ifo = 2*sum(S_pred,2)/L^2;
        

% Calculate whole frequency spectrum

Sens = zeros(length(freq),length(S_ifo));

for i1 = 1:length(S_ifo)
    Sens(:,i1) = (freq.^-2) * S_ifo(i1) * 100^2;
end

% Convert to amplitude spectral density
Asens_LandT = sqrt(Sens);

% Plot like crazy
f = figure(...
    'paperunits','inches',...
    'units','inches',...
    'papersize',[8,5],...
    'paperposition',[0,0,8,5],...
    'position',[5,5,8,5]);
h = zeros(size(ColorSet,1),1);
for i1 = 1:size(ColorSet,1)
    x = freq;
    if i1 == 1
        y = L1sens;
    elseif i1 == 2
        y = sqrt(Sens_gwinc);
    else
        y = Asens_LandT(:,i1-2);
    end
    C = ColorSet(i1,:);
    h(i1) = loglog(x,y,'color',C,'linewidth',2);
    hold on
end

xlim([10,6e3]);
ylim([1e-24,1e-20])
xlabel('Frequency [Hz]','fontsize',18,'fontweight','demi');
ylabel('Strain [Hz^{-1/2}]','fontsize',18,'fontweight','demi');
set(gca,'linewidth',2,'fontsize',15,'fontweight','demi');
l=legend(h,LegendStrings);        

print(f,'LiuThorneScaling.pdf','-dpdf');
print(f,'LiuThorneScaling.png','-dpng','-r500');

Data = [freq,Asens_LandT];
csvwrite('LandTScalingData.csv',Data);
    
%% Somiya Scaling

% Input of Energy values
% These values are calculated using Somiya.m
Cftm = [... % Finite substrate correction factor from Somiya, eqn 28
    0.9995,... % TNI 1
    0.9995,... % TNI 2
    0.9995,... % TNI 3
    0.9995,... % TNI 4
    1.0057...  % TNC
    ];

Cftm_pred = [... % Finite substrate correction factor for predicted optics
    0.9691,... % ITM
    0.9534 ... % ETM
    ];

% Calculate displacement sensitivity for individual mirrors
S_pred = zeros(length(d),length(d_pred));

for i1 = 1:length(d)
    for i2 = 1:length(d_pred)
        S_pred(i1,i2) = ...
              d_pred(i2)/d(i1)...
            * Cftm_pred(i2)/Cftm(i1)...
            * (w(i1)/w_pred(i2))^2 ...
            * S(i1);
    end
end

% Calculate strain sensitivity for the whole IFO

S_ifo = 2*sum(S_pred,2)/L^2;
        

% Calculate whole frequency spectrum

Sens = zeros(length(freq),length(S_ifo));

for i1 = 1:length(S_ifo)
    Sens(:,i1) = (freq.^-2) * S_ifo(i1) * 100^2;
end

% Convert to amplitude spectral density
Asens_Somiya = sqrt(Sens);

% Plot like crazy
f = figure(...
    'paperunits','inches',...
    'units','inches',...
    'papersize',[8,5],...
    'paperposition',[0,0,8,5],...
    'position',[5,5,8,5]);
h = zeros(size(ColorSet,1),1);
for i1 = 1:size(ColorSet,1)
    x = freq;
    if i1 == 1
        y = L1sens;
    elseif i1 == 2
        y = sqrt(Sens_gwinc);
    else
        y = Asens_Somiya(:,i1-2);
    end
    C = ColorSet(i1,:);
    h(i1) = loglog(x,y,'color',C,'linewidth',2);
    hold on
end

xlim([10,6e3]);
ylim([1e-24,1e-20])
xlabel('Frequency [Hz]','fontsize',18,'fontweight','demi');
ylabel('Strain [Hz^{-1/2}]','fontsize',18,'fontweight','demi');
set(gca,'linewidth',2,'fontsize',15,'fontweight','demi');
l=legend(h,LegendStrings);        

print(f,'SomiyaScaling.pdf','-dpdf');
print(f,'SomiyaScaling.png','-dpng','-r500');

Data = [freq,Asens_Somiya];
csvwrite('SomiyaScalingData.csv',Data);

%% Make some comparison Plots
%clear(h);
for i1 = 1:size(Asens_Somiya,2)
    clear h
    h = zeros(5,1);
    f = figure(...
       'paperunits','inches',...
       'units','inches',...
       'papersize',[8,5],...
       'paperposition',[0,0,8,5],...
       'position',[5,5,8,5]); 
   
    x = freq;
    h(1) = loglog(x,L1sens,'color',ColorSet(1,:),'linewidth',2);
    hold on
    h(2) = loglog(x,sqrt(Sens_gwinc),'color',ColorSet(2,:),'linewidth',2);
    h(3) = loglog(x,Asens_simple(:,i1),'color',ColorSet(i1+2,:),'linewidth',2,'linestyle','-');
    h(4) = loglog(x,Asens_LandT(:,i1),'color',ColorSet(i1+2,:),'linewidth',2,'linestyle','--');
    h(5) = loglog(x,Asens_Somiya(:,i1),'color',ColorSet(i1+2,:),'linewidth',2,'linestyle','-.');
    
    xlim([10,500]);
    ylim([1e-24,1e-22])
    xlabel('Frequency [Hz]','fontsize',18,'fontweight','demi');
    ylabel('Strain [Hz^{-1/2}]','fontsize',18,'fontweight','demi');
    set(gca,'linewidth',2,'fontsize',15,'fontweight','demi');
    l=legend(h,'L1 Sensitivity',...
        'GWINC',...
        'Simple Scaling',...
        'Liu and Thorne Scaling',...
        'Somiya Scaling');
    title(['Comparison of Scaling for scaled measurements from ',char(LegendStrings(i1+2))]);
    
    FileName = ['ScalingCompare_',char(LegendStrings(i1+2))];
    print(f,[FileName,'.pdf'],'-dpdf');
    print(f,[FileName,'.png'],'-dpng','-r500');
    
end



